===============================
cn_stock_daily
===============================


.. image:: https://img.shields.io/pypi/v/csdaily.svg
        :target: https://pypi.python.org/pypi/csdaily

.. image:: https://img.shields.io/travis/qytz/cn_stock_daily.svg
        :target: https://travis-ci.org/qytz/cn_stock_daily

.. image:: https://readthedocs.org/projects/csdaily/badge/?version=latest
        :target: https://csdaily.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/qytz/cn_stock_daily/shield.svg
     :target: https://pyup.io/repos/github/qytz/cn_stock_daily/
     :alt: Updates


China Stock Daily


* Free software: Apache License 2.0
* Documentation: https://csdaily.readthedocs.io.


Features
--------

* TODO
